| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.ELBV2.Types.Listener
Description
Synopsis
- data Listener = Listener' {
- alpnPolicy :: Maybe [Text]
- certificates :: Maybe [Certificate]
- defaultActions :: Maybe [Action]
- listenerArn :: Maybe Text
- loadBalancerArn :: Maybe Text
- port :: Maybe Natural
- protocol :: Maybe ProtocolEnum
- sslPolicy :: Maybe Text
- newListener :: Listener
- listener_alpnPolicy :: Lens' Listener (Maybe [Text])
- listener_certificates :: Lens' Listener (Maybe [Certificate])
- listener_defaultActions :: Lens' Listener (Maybe [Action])
- listener_listenerArn :: Lens' Listener (Maybe Text)
- listener_loadBalancerArn :: Lens' Listener (Maybe Text)
- listener_port :: Lens' Listener (Maybe Natural)
- listener_protocol :: Lens' Listener (Maybe ProtocolEnum)
- listener_sslPolicy :: Lens' Listener (Maybe Text)
Documentation
Information about a listener.
See: newListener smart constructor.
Constructors
| Listener' | |
Fields
| |
Instances
newListener :: Listener Source #
Create a value of Listener with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:alpnPolicy:Listener', listener_alpnPolicy - [TLS listener] The name of the Application-Layer Protocol Negotiation
(ALPN) policy.
$sel:certificates:Listener', listener_certificates - [HTTPS or TLS listener] The default certificate for the listener.
$sel:defaultActions:Listener', listener_defaultActions - The default actions for the listener.
$sel:listenerArn:Listener', listener_listenerArn - The Amazon Resource Name (ARN) of the listener.
$sel:loadBalancerArn:Listener', listener_loadBalancerArn - The Amazon Resource Name (ARN) of the load balancer.
$sel:port:Listener', listener_port - The port on which the load balancer is listening.
$sel:protocol:Listener', listener_protocol - The protocol for connections from clients to the load balancer.
$sel:sslPolicy:Listener', listener_sslPolicy - [HTTPS or TLS listener] The security policy that defines which protocols
and ciphers are supported.
listener_alpnPolicy :: Lens' Listener (Maybe [Text]) Source #
- TLS listener
- The name of the Application-Layer Protocol Negotiation (ALPN) policy.
listener_certificates :: Lens' Listener (Maybe [Certificate]) Source #
- HTTPS or TLS listener
- The default certificate for the listener.
listener_defaultActions :: Lens' Listener (Maybe [Action]) Source #
The default actions for the listener.
listener_listenerArn :: Lens' Listener (Maybe Text) Source #
The Amazon Resource Name (ARN) of the listener.
listener_loadBalancerArn :: Lens' Listener (Maybe Text) Source #
The Amazon Resource Name (ARN) of the load balancer.
listener_port :: Lens' Listener (Maybe Natural) Source #
The port on which the load balancer is listening.
listener_protocol :: Lens' Listener (Maybe ProtocolEnum) Source #
The protocol for connections from clients to the load balancer.